# chess-hic

![PyPI version](https://badge.fury.io/py/chess-hic.svg)
![Documentation Status](https://readthedocs.org/projects/chess-hic/badge/?version=latest)

CHESS is a tool for the comparison and automatic feature extraction for chromatin contact data,
developed in the [Vaquerizas Lab](https://www.vaquerizaslab.org/).

Please check out the [online documentation](https://chess-hic.readthedocs.io/en/latest/index.html)
for detailed installation and usage instructions.